@@ -24,12 +24,22 @@ def parseUrl(url):
     return address, req_port, sub_port
 
 
-def connect(url, motorcortex_types, param_tree, **kwargs):
+def connect(url, motorcortex_types, param_tree, reconnect=True, **kwargs):
+    if reconnect and not kwargs.get("state_update"):
+        def stateUpdate(req, sub, state):
+            if state == ConnectionState.CONNECTION_OK:
+                req.login(kwargs.get("login"), kwargs.get("password")).get()
+                sub.resubscribe().get()
+
+        kwargs.update(state_update=stateUpdate)
+
     # Parse address
     address, req_port, sub_port = parseUrl(url)
     # Open request connection
     req = Request(motorcortex_types, param_tree)
-    if not req.connect("{}:{}".format(address, req_port), **kwargs).get():
+    kwargs_copy = kwargs.copy()
+    kwargs_copy.update(state_update=None)
+    if not req.connect("{}:{}".format(address, req_port), **kwargs_copy).get():
         raise RuntimeError("Failed to establish request connection: {}:{}".format(address, req_port))
     # Open subscribe connection
     sub = Subscribe(req, motorcortex_types)
