@@ -14,9 +14,17 @@ import os
 if sys.version_info[0] >= 3:
     from importlib.machinery import SourceFileLoader
 
+    if sys.version_info[1] < 4:
+        def importLibrary(name, path):
+            return SourceFileLoader(name, path).load_module()
+    else:
+        from types import ModuleType
 
-    def importLibrary(name, path):
-        return SourceFileLoader(name, path).load_module()
+
+        def importLibrary(name, path):
+            loader = SourceFileLoader(name, path)
+            mod = ModuleType(loader.name)
+            return loader.exec_module(mod)
 else:
     from builtins import bytes
     from imp import load_source
