@@ -5,7 +5,7 @@
 #   All rights reserved. Copyright (c) 2016 VECTIONEER.
 #
 
-from motorcortex.request import Request
+from motorcortex.request import Request, ConnectionState
 from motorcortex.request import Reply
 from motorcortex.subscription import Subscription
 from pynng import Sub0, TLSConfig
@@ -32,6 +32,8 @@ class Subscribe:
         self.__protobuf_types = protobuf_types
         self.__subscriptions = dict()
         self.__pool = ThreadPoolExecutor()
+        self.__clb = ThreadPoolExecutor(max_workers=1)
+        self.__connection_state = ConnectionState.DISCONNECTED
 
     def connect(self, url, **kwargs):
         """Open a subscribe connection.
@@ -40,9 +42,10 @@ class Subscribe:
                 url(str): motorcortex server URL
 
             Returns:
-                bool: True - if connected, False otherwise
+                bool: True - if connected, False othesudo apt-get install python-devrwise
         """
 
+        self.__connection_state = ConnectionState.CONNECTING
         conn_timeout_ms, recv_timeout_ms, certificate, state_update = Request.parse(**kwargs)
         if recv_timeout_ms == 0:
             recv_timeout_ms = 500
@@ -58,9 +61,20 @@ class Subscribe:
 
         def pre_connect_cb(pipe):
             self.__connected_lock.put(True)
+            self.__connection_state = ConnectionState.CONNECTION_OK
+            if state_update:
+                self.__clb.submit(state_update, self.__req, self, self.connectionState())
 
         def post_remove_cb(pipe):
+            if self.__connection_state == ConnectionState.DISCONNECTING:
+                self.__connection_state = ConnectionState.DISCONNECTED
+            elif self.__connection_state == ConnectionState.CONNECTING:
+                self.__connection_state = ConnectionState.CONNECTION_FAILED
+            elif self.__connection_state == ConnectionState.CONNECTION_OK:
+                self.__connection_state = ConnectionState.CONNECTION_LOST
             self.__connected_lock.put(False)
+            if state_update:
+                self.__clb.submit(state_update, self.__req, self, self.connectionState())
 
         self.__socket.add_pre_pipe_connect_cb(pre_connect_cb)
         self.__socket.add_post_pipe_remove_cb(post_remove_cb)
@@ -71,8 +85,15 @@ class Subscribe:
         return Reply(self.__pool.submit(Request.waitForConnection, self.__connected_lock,
                                         conn_timeout_ms / 1000.0))
 
+    def resubscribe(self):
+        print("resubscribe")
+        for _, s in self.__subscriptions.items():
+            print(f"resubscribe: {s}")
+            self.__req.createGroup(s.layout(), s.alias(), s.frqDivider())
+
     def close(self):
         """Close connection to the server"""
+        self.__connection_state = ConnectionState.DISCONNECTING
         if self.__connected_lock:
             self.__connected_lock.put(False)
         self.__socket.close()
@@ -111,7 +132,7 @@ class Subscribe:
                   is ready the handle is used to retrieve latest data.
         """
 
-        subscription = Subscription(group_alias, self.__protobuf_types)
+        subscription = Subscription(group_alias, self.__protobuf_types, frq_divider)
         reply = self.__req.createGroup(param_list, group_alias, frq_divider)
         reply.then(self.__complete, subscription, self.__socket).catch(
             subscription._failed)
@@ -148,6 +169,9 @@ class Subscribe:
         # send remove group request to the server
         return self.__req.removeGroup(subscription.alias())
 
+    def connectionState(self):
+        return self.__connection_state
+
     def __complete(self, msg, subscription, socket):
         if subscription._complete(msg):
             id_buf = bytes([msg.id & 0xff, (msg.id >> 8) & 0xff, (msg.id >> 16) & 0xff])
