@@ -83,6 +83,40 @@ class OpenSubscribeConnection(unittest.TestCase):
         sub.close()
         req.close()
 
+class Reconnection(unittest.TestCase):
+
+    def stateChange(self, req, sub, state):
+        print(f"obj: {req} state change: {state}")
+        if state == motorcortex.ConnectionState.CONNECTION_OK:
+            print("connected")
+            res = req.login("root", "vectioneer").get()
+            sub.resubscribe()
+            print(res)
+        if state == motorcortex.ConnectionState.CONNECTION_LOST:
+            print("connection lost")
+        if state == motorcortex.ConnectionState.DISCONNECTED:
+            print(f"disconnected")
+    def test(self):
+        # Open subscribe connection
+        # Creating empty object for parameter tree
+        parameter_tree = motorcortex.ParameterTree()
+
+        # Loading protobuf types and hashes
+        motorcortex_types = motorcortex.MessageTypes()
+
+        # Open request connection
+        req, sub = motorcortex.connect("wss://127.0.0.1:5568:5567", motorcortex_types, parameter_tree,
+                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       login="root", password="vectioneer")
+
+
+        sub.subscribe(["root/Comm_task/actual_cycle_max"], "test").notify(lambda x : print(x))
+
+
+        time.sleep(10000)
+        sub.close()
+        req.close()
+
 
 class Login(unittest.TestCase):
 
